@@ -2,7 +2,7 @@
 /*
  *  argument.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 15 Jul 2008 05:04:00 JST
+ *  Last-modified: Fri 17 Apr 2009 05:04:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_ARGUMENT_H
@@ -78,19 +78,22 @@ namespace clx {
 		
 		// operator
 		basic_argument& assign(int argc, char_type* argv[]) {
+			static const char_type zero = LITERAL('0');
+			static const char_type nine = LITERAL('9');
+			
 			program_ = argv[0];
 			string_type key;
 			bool eoh = false; // end of head parameter
 			for (int i = 1; i < argc; ++i) {
 				string_type tmp(argv[i]);
-				if (tmp.at(0) == identifier_) { // make a new entry
+				if (tmp.at(0) == identifier_ && tmp.size() > 1 &&
+					!(tmp.at(1) >= zero && tmp.at(1) <= nine)) {
 					eoh = true;
-					if (tmp.size() > 2 && tmp.at(1) != identifier_) {
+					if (tmp.at(1) != identifier_) {
 						for (size_type j = 1; j < tmp.size(); ++j) {
 							key = tmp.at(j);
 							this->set_param(key, string_type());
 						}
-						key.clear();
 					}
 					else {
 						key = tmp.substr(tmp.find_first_not_of(identifier_));
