@@ -2,7 +2,7 @@
 /*
  *  exception.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,21 +29,18 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 21 Oct 2008 10:33:00 JST
+ *  Last-modified: Thu 02 Apr 2009 10:05:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_EXCEPTION_H
 #define CLX_EXCEPTION_H
 
-#ifndef CLX_WIN32
-//#if defined(_MSC_VER) && (_MSC_VER >= 1200)
-#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32)
-#define CLX_WIN32
-#endif
-#endif // CLX_WIN32
+#include "config.h"
 
 #include <exception>
 #include <stdexcept>
+#include <string>
+#include <sstream>
 
 #ifdef CLX_WIN32
 #include "win32/system_error.h"
