@@ -2,7 +2,7 @@
 /*
  *  mutex.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -33,17 +33,13 @@
  *  accompanying file LICENSE_1_0.txt or copy at
  *  http://www.boost.org/LICENSE_1_0.txt)
  *
- *  Last-modified: Mon 19 Aug 2008 14:01:23 JST
+ *  Last-modified: Thu 02 Apr 2009 10:07:23 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_MUTEX_H
 #define CLX_MUTEX_H
 
-#ifndef CLX_WIN32
-#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32)
-#define CLX_WIN32
-#endif
-#endif // CLX_WIN32
+#include "config.h"
 
 #ifdef CLX_WIN32
 #include "win32/mutex.h"
